==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/eu.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "gordetzen...",
    "saved!" : "gordeta!",
    "failed!" : "errorea!",
    "Saved" : "Gordeta",
    "There was a problem saving your changes. Click to resume editing." : "Aldaketak gordetzean errorea egon da. Klik egin edizioarekin jarraitzeko",
    "An error occurred!" : "Errore bat gertatu da!",
    "Edit" : "Editatu",
    "Mixed" : "Nahastua",
    "Preview" : "Aurrebista",
    "New text file" : "Testu fitxategi berria",
    "New text file.txt" : "file.txt testu fitxategi berria",
    "You can not open a folder" : "Ezin duzu karpeta bat ireki",
    "This file is too big to be opened. Please download the file instead." : "Fitxategia handiegia da irekitzeko. Jaitsi fitxategia mesedez.",
    "Cannot read the file." : "Ezin da fitxategia irakurri.",
    "Invalid file path supplied." : "Fitxategiaren helbide ezegokia.",
    "The file is locked." : "Fitxategia blokeatuta dago.",
    "An internal server error occurred." : "Barne errorea gertatu da.",
    "You can not write to a folder" : "Ezin duzu karpetan idatzi",
    "Cannot save file as it has been modified since opening" : "Ezin da fitxategia gorde ireki denetik aldatu delako",
    "Insufficient permissions" : "Baimen gutxiegi",
    "File path not supplied" : "Ez da fitxategiaren helbidea idatzi",
    "File mtime not supplied" : "Fitxategiaren mtime-a ez da ezarri",
    "Text editor" : "Testu editorea",
    "Text file" : "Testu fitxategia"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/eu.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "gordetzen...",
    "saved!" : "gordeta!",
    "failed!" : "errorea!",
    "Saved" : "Gordeta",
    "There was a problem saving your changes. Click to resume editing." : "Aldaketak gordetzean errorea egon da. Klik egin edizioarekin jarraitzeko",
    "An error occurred!" : "Errore bat gertatu da!",
    "Edit" : "Editatu",
    "Mixed" : "Nahastua",
    "Preview" : "Aurrebista",
    "New text file" : "Testu fitxategi berria",
    "New text file.txt" : "file.txt testu fitxategi berria",
    "You can not open a folder" : "Ezin duzu karpeta bat ireki",
    "This file is too big to be opened. Please download the file instead." : "Fitxategia handiegia da irekitzeko. Jaitsi fitxategia mesedez.",
    "Cannot read the file." : "Ezin da fitxategia irakurri.",
    "Invalid file path supplied." : "Fitxategiaren helbide ezegokia.",
    "The file is locked." : "Fitxategia blokeatuta dago.",
    "An internal server error occurred." : "Barne errorea gertatu da.",
    "You can not write to a folder" : "Ezin duzu karpetan idatzi",
    "Cannot save file as it has been modified since opening" : "Ezin da fitxategia gorde ireki denetik aldatu delako",
    "Could not write to file." : "Ezin izan da fitxategian idatzi.",
    "Insufficient permissions" : "Baimen gutxiegi",
    "File path not supplied" : "Ez da fitxategiaren helbidea idatzi",
    "File mtime not supplied" : "Fitxategiaren mtime-a ez da ezarri",
    "Text editor" : "Testu editorea"
},
"nplurals=2; plural=(n != 1);");
